@@ -13,14 +13,14 @@
 #' result <- check_collinearity(m)
 #' result
 #' plot(result)
-#' @importFrom rlang .data
+#' @importFrom ggplot2 .data
 #' @export
 plot.see_check_collinearity <- function(x,
                                         data = NULL,
                                         colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
                                         ...) {
   if (is.null(data)) {
-    dat <- .compact_list(.retrieve_data(x))
+    dat <- datawizard::compact_list(.retrieve_data(x))
   } else {
     dat <- data
   }
