@@ -189,7 +189,7 @@ data_plot.bayestestR_eti <- data_plot.hdi
 #' @param show_title Logical. If `TRUE`, will show the title of the plot.
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
-#' @inheritParams plot.see_cluster_analysis
+#' @inheritParams plot.see_parameters_model
 #'
 #' @return A ggplot2-object.
 #'
@@ -203,7 +203,7 @@ data_plot.bayestestR_eti <- data_plot.hdi
 #'   plot(result)
 #' }
 #' }
-#' @importFrom rlang .data
+#' @importFrom ggplot2 .data
 #' @export
 plot.see_hdi <- function(x,
                          data = NULL,
@@ -225,6 +225,8 @@ plot.see_hdi <- function(x,
   # get labels
   labels <- .clean_parameter_names(x$y, grid = !is.null(n_columns))
 
+  insight::check_if_installed("ggridges")
+
   p <- ggplot(
     as.data.frame(x),
     aes(
