@@ -1,7 +1,7 @@
 #' See color palette
 #'
-#' The See color palette. Use \code{scale_color_see_d()} for \emph{discrete}
-#' categories and \code{scale_color_see_c()} for a \emph{continuous} scale.
+#' The See color palette. Use `scale_color_see_d()` for *discrete*
+#' categories and `scale_color_see_c()` for a *continuous* scale.
 #'
 #' @inheritParams palette_see
 #' @inheritParams scale_color_flat
@@ -25,7 +25,10 @@
 #'   theme_modern() +
 #'   scale_color_see_c(palette = "rainbow")
 #' @export
-scale_color_see <- function(palette = "contrast", discrete = TRUE, reverse = FALSE, ...) {
+scale_color_see <- function(palette = "contrast",
+                            discrete = TRUE,
+                            reverse = FALSE,
+                            ...) {
   pal <- palette_see(palette = palette, reverse = reverse)
 
   if (discrete) {
@@ -42,14 +45,30 @@ scale_color_see <- function(palette = "contrast", discrete = TRUE, reverse = FAL
 
 #' @rdname scale_color_see
 #' @export
-scale_color_see_d <- function(palette = "contrast", discrete = TRUE, reverse = FALSE, ...) {
-  scale_color_see(palette = palette, discrete = discrete, reverse = reverse, ...)
+scale_color_see_d <- function(palette = "contrast",
+                              discrete = TRUE,
+                              reverse = FALSE,
+                              ...) {
+  scale_color_see(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    ...
+  )
 }
 
 #' @rdname scale_color_see
 #' @export
-scale_color_see_c <- function(palette = "contrast", discrete = FALSE, reverse = FALSE, ...) {
-  scale_color_see(palette = palette, discrete = discrete, reverse = reverse, ...)
+scale_color_see_c <- function(palette = "contrast",
+                              discrete = FALSE,
+                              reverse = FALSE,
+                              ...) {
+  scale_color_see(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    ...
+  )
 }
 
 #' @rdname scale_color_see
@@ -74,7 +93,10 @@ scale_colour_see_d <- scale_color_see_d
 
 #' @rdname scale_color_see
 #' @export
-scale_fill_see <- function(palette = "contrast", discrete = TRUE, reverse = FALSE, ...) {
+scale_fill_see <- function(palette = "contrast",
+                           discrete = TRUE,
+                           reverse = FALSE,
+                           ...) {
   pal <- palette_see(palette = palette, reverse = reverse)
 
   if (discrete) {
@@ -87,25 +109,37 @@ scale_fill_see <- function(palette = "contrast", discrete = TRUE, reverse = FALS
 
 #' @rdname scale_color_see
 #' @export
-scale_fill_see_d <- function(palette = "contrast", discrete = TRUE, reverse = FALSE, ...) {
-  scale_fill_see(palette = palette, discrete = discrete, reverse = reverse, ...)
+scale_fill_see_d <- function(palette = "contrast",
+                             discrete = TRUE,
+                             reverse = FALSE,
+                             ...) {
+  scale_fill_see(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    ...
+  )
 }
 
 #' @rdname scale_color_see
 #' @export
-scale_fill_see_c <- function(palette = "contrast", discrete = FALSE, reverse = FALSE, ...) {
-  scale_fill_see(palette = palette, discrete = discrete, reverse = reverse, ...)
+scale_fill_see_c <- function(palette = "contrast",
+                             discrete = FALSE,
+                             reverse = FALSE,
+                             ...) {
+  scale_fill_see(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    ...
+  )
 }
 
 
 
-
-
 # Palette --------------------------------------------------------------------
 
 
-
-
 see_colors_list <- c(
   `red` = "#d32626",
   `pink` = "#b5076b",
@@ -128,7 +162,8 @@ see_colors_list <- c(
 
 #' Extract See colors as hex codes
 #'
-#' Can be used to get the hex code of specific colors from the See color palette. Use \code{see_colors()} to see all available color.
+#' Can be used to get the hex code of specific colors from the See color
+#' palette. Use `see_colors()` to see all available color.
 #'
 #' @inheritParams flat_colors
 #'
@@ -150,8 +185,6 @@ see_colors <- function(...) {
 }
 
 
-
-
 see_palettes <- list(
   `full` = see_colors(),
   `ice` = see_colors("indigo", "blue", "blue grey", "cyan", "light blue"),
@@ -162,20 +195,13 @@ see_palettes <- list(
 )
 
 
-
-
-
-
 #' See design color palette
 #'
-#' See design color palette.
-#'
 #' @inheritParams palette_flat
 #'
 #' @details This function is usually not called directly, but from within
-#'   \code{\link[=scale_color_see]{scale_color_see()}}.
+#'   [`scale_color_see()`][scale_color_see].
 #'
-#' @importFrom grDevices colorRampPalette
 #' @export
 palette_see <- function(palette = "contrast", reverse = FALSE, ...) {
   pal <- see_palettes[[palette]]
