@@ -1,5 +1,10 @@
-if (getRversion() >= "4.1" && require("vdiffr") && require("ggplot2") &&
-  require("performance") && require("lme4") && require("see") && require("qqplotr")) {
+if (getRversion() >= "4.1" && getRversion() < "4.2" &&
+  require("vdiffr") &&
+  require("ggplot2") &&
+  require("performance") &&
+  require("lme4") &&
+  require("see") &&
+  require("qqplotr")) {
   test_that("`plot.see_check_normality()` works", {
     skip_on_cran()
 
