@@ -1,4 +1,6 @@
-if (getRversion() >= "4.1" && require("vdiffr") && require("ggplot2")) {
+if (getRversion() >= "4.1" && getRversion() < "4.2" &&
+  require("vdiffr") &&
+  require("ggplot2")) {
   test_that("scale_color_ functions work correctly", {
     skip_on_cran()
 
